.. _astro-source:

****************************************************
Astrophysical source models (`gammapy.astro.source`)
****************************************************

.. currentmodule:: gammapy.astro.source

Introduction
============

The `gammapy.astro.source` module contains classes of source models, which can
be used for population synthesis of galactic gamma-ray sources.

Getting Started
===============

TODO: add basic example.

Using `gammapy.astro.source`
============================

The following source models are available:

.. toctree::
    :maxdepth: 1

    snr
    pwn
    pulsar

Reference/API
=============

.. automodapi:: gammapy.astro.source
    :no-inheritance-diagram:
    :include-all-objects:
